#!/bin/tcsh -ef
#
# Setup environment for MNI-BIC tools
#
# MNI_INSTALL_DIR defines where the files are installed.  
# PERL5LIB defines where perl will look for its MNI utils, like 
# MNI/Startup.pm.  
#

#set echo=1

if (! $?MNI_INSTALL_DIR) then
    echo "ERROR! MNI_INSTALL_DIR must be defined!"
    exit 1
endif
if ( ! $?PERL5LIB) then
    echo "ERROR! PERL5LIB must be defined!  Determine using perl -V"
    exit 1
endif
if ( ! -e $PERL5LIB) then
    echo "Warning! PERL5LIB '$PERL5LIB' directory does not exist!"
endif

## Set this environment variable to suppress the output.
if( $?FS_FREESURFERENV_NO_OUTPUT ) then
    set output = 0
else
    set output = 1
endif
if($?USER == 0 || $?prompt == 0) then
    set output = 0
endif
if( $output ) then
    echo "SetupMniEnv:"
    echo "MNI_INSTALL_DIR $MNI_INSTALL_DIR"
    echo "PERL5LIB        $PERL5LIB"
endif

#
# The following generally do not need modification:
#

setenv MNI_DIR               "$MNI_INSTALL_DIR"

setenv MINC_BIN_DIR          "$MNI_DIR/bin"
setenv MINC_LIB_DIR          "$MNI_DIR/lib"

if (! $?PATH) then
    setenv PATH              "$MINC_BIN_DIR"
else
    setenv PATH              "$MINC_BIN_DIR":"$PATH"
endif

#if (! $?LD_INCLUDE_PATH) then
#    setenv LD_INCLUDE_PATH   "$MNI_DIR/include"
#else
#    setenv LD_INCLUDE_PATH   "$MNI_DIR/include":"$LD_INCLUDE_PATH"
#endif

if (! $?LD_LIBRARY_PATH) then
    setenv LD_LIBRARY_PATH   "$MNI_DIR/lib"
else
    setenv LD_LIBRARY_PATH   "$MNI_DIR/lib":"$LD_LIBRARY_PATH"
endif

if (! $?DYLD_LIBRARY_PATH) then
    setenv DYLD_LIBRARY_PATH "$MNI_DIR/lib"
else
    setenv DYLD_LIBRARY_PATH "$MNI_DIR/lib":"$DYLD_LIBRARY_PATH"
endif

#if (! $?LD_RUN_PATH) then
#    setenv LD_RUN_PATH       "$MNI_DIR/lib"
#else
#    setenv LD_RUN_PATH       "$MNI_DIR/lib":"$LD_RUN_PATH"
#endif

# force update of paths
rehash

